package de.intevation.artifactdatabase;

import java.util.List;

/**
 * Class to model the concept of an 'id' in terms of unique integer as
 * used in databases. Subclasses of this class are able to be processed
 * by this id.
 *
 * @author <a href="mailto:sascha.teichmann@intevation.de">Sascha L. Teichmann</a>
 */
public class Id
{
    /**
     * Interface to filter a list of ids.
     */
    public interface Filter {
        /**
         * A list of ids is processed in a functional way to be
         * free from some ids by the implementing code. The resulting
         * list maybe short or equal sized to the original one. The
         * original list is not modified.
         * @param ids The list of input ids.
         * @return A list of processed ids.
         */
        List filterIds(List ids);
    }

    /**
     * The backing int of the id.
     */
    protected int id;

    /**
     * Default constructor: id = 0
     */
    public Id() {
    }

    /**
     * Constructor to create an id with a given value.
     * @param id The id value
     */
    public Id(int id) {
        this.id = id;
    }

    /**
     * Returns the id value.
     * @return The value of the id.
     */
    public int getId() {
        return id;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
