package de.intevation.artifactdatabase.rest;

import org.restlet.representation.Representation;
import org.restlet.representation.EmptyRepresentation;

import org.restlet.ext.xml.DomRepresentation;

import de.intevation.artifacts.ArtifactDatabase;
import de.intevation.artifacts.ArtifactDatabaseException;

import org.restlet.data.Request;
import org.restlet.data.Response;
import org.restlet.data.Status;
import org.restlet.data.MediaType;

import org.apache.log4j.Logger;

import org.w3c.dom.Document;

import java.io.IOException;

/**
 * Resource to process incoming XML documents with a given service.
 *
 * @author <a href="mailto:sascha.teichmann@intevation">Sascha L. Teichmann</a>
 */
public class ServiceResource
extends      BaseResource
{
    private static Logger logger = Logger.getLogger(ServiceResource.class);

    /**
     * server URL where to reach the resource.
     */
    public static final String PATH = "/service/{service}";

    /**
     * Error message if no corresponing service is provided by
     * the artifact database.
     */
    public static final String NO_SUCH_ACTION_MESSAGE = "no such service";

    @Override
    protected Representation innerPost(Representation requestRepr) {

        Document inputDocument = null;
        try {
            DomRepresentation input = new DomRepresentation(requestRepr);
            input.setNamespaceAware(true);
            inputDocument = input.getDocument();
        }
        catch (IOException ioe) {
            logger.error(ioe.getMessage());
            Response response = getResponse();
            response.setStatus(Status.CLIENT_ERROR_BAD_REQUEST, ioe);
            return new EmptyRepresentation();
        }

        Request request = getRequest();

        String service = (String)request.getAttributes().get("service");

        ArtifactDatabase db = (ArtifactDatabase)getContext()
            .getAttributes().get("database");

        try {
            return new DomRepresentation(
                MediaType.APPLICATION_XML,
                db.process(service, inputDocument, getCallMeta()));
        }
        catch (ArtifactDatabaseException adbe) {
            logger.warn(adbe.getLocalizedMessage(), adbe);
            Response response = getResponse();
            response.setStatus(
                Status.CLIENT_ERROR_BAD_REQUEST, adbe.getMessage());
            return new EmptyRepresentation();
        }
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
